=begin
Copyright 2018 (c) TIG
All Rights Reserved.
THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED 
WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF 
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
Usage:
Preselect geometry [containing some edges] and/or containers [group/component-instance].
Menu: Edit > Remove Edge Material
Or type in Ruby Console TIG::RemoveEdgeMaterial.now
=end

module TIG

  module RemoveEdgeMaterial
  
    # menu set up
    unless @menu
      UI.menu('Edit').add_item('Remove Edge Material'){ self.now() }
    end
    @menu = true
    #
  
    def self.now()
      @count = 0
      model = Sketchup.active_model
      ss = model.selection
       model.start_operation('Remove Edge Material', true) # one step undo
      if es = ss.grep(Sketchup::Edge) # process selected edges
        self.process_edges(es)
      end
      if gs = ss.grep(Sketchup::Group)
        self.default_groups(gs)
      end
      if cs = ss.grep(Sketchup::ComponentInstance)
        self.default_compos(cs)
      end
      ss.clear
      unless es[0] || gs[0] || cs[0]
        UI.messagebox("Remove Edge Material:\n\nMust Preselect Geometry with Edges and/or Groups/Components...")
        model.abort_operation
      else
        UI.messagebox("#{@count} Edges Material Removed.")
        model.commit_operation
      end
    end
    
    def self.process_edges(es=[]) # default passed edges
      es.each{|e|
        if e.material
          e.material = nil
          @count+=1
        end
      }
    end
    
    def self.default_groups(gs=[]) # nested in groups
      gs.each{|g|
        es = g.entities.grep(Sketchup::Edge)
        self.process_edges(es)
        g.entities.grep(Sketchup::Group).each{|gg| self.default_groups([gg]) }
        g.entities.grep(Sketchup::ComponentInstance).each{|cc| self.default_compos([cc]) }
      }
    end
    
    def self.default_compos(cs=[]) # nested in definitions
      cs.each{|c|
        es = c.definition.entities.grep(Sketchup::Edge)
        self.process_edges(es)
        c.definition.entities.grep(Sketchup::Group).each{|gg| self.default_groups([gg]) }
        c.definition.entities.grep(Sketchup::ComponentInstance).each{|cc| self.default_compos([cc]) }
      }
    end
    
  end
  
end
